==> nextcloud-21.0.8p0.tgz: nextcloud/apps/survey_client/l10n/sc.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Ùrtima relata imbiada su: {on}",
    "An error occurred while sending your report." : "B'at àpidu un'errore in s'imbiu de su torracontu.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Elencu de aplicatziones <em>(pro cada aplicatzione: nùmene, versione, istadu de ativatzione)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente de sa base de datos <em>(genia, versione, mannària de sa base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informatziones de tzifradura <em>(ativada est?, cal'est su mòdulu predefinidu)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Nùmeru de cumpartziduras <em>(pro genia e permissos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versione, lìmite di memòria, tempu de esecutzione max., mannària de is archìvios max.)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detàllios istàntzia de su serbidore<em>(versione, memcache impreada, istadu de blocu/anteprimas/avatar)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Istatìsticas <em>(nùmeru de archìvios: archìviu, utentes, archiviatziones pro genia, cummentos e etichetas)</em>",
    "Usage survey" : "Sondàgiu de impreu",
    "Help improve Nextcloud" : "Agiuda·nos a megiorare Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nos boles agiudare a megiorare Nextcloud fruninde unos cantos datos in forma anònima in contu de sa cunfiguratzione e impreu tuos? Podes disativare in cada momentu in is impostatziones de amministratzione.",
    "Not now" : "No immoe",
    "Send usage" : "Imbia impreu",
    "Never" : "Mai",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Imbia datos in forma anònima a Nextcloud pro nos agiudare a ddu megiorare.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Imbia datos in forma anònima a Nextcloud pro nos agiudare a megiorare Nextcloud. As a tènnere\n        semper su controllu prenu de is cuntenutos imbiados a  Nextcloud e podes disabilitare\n        custa funtzione in cada momentu.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Podes cuntribuire a megiorare Nextcloud imbiende unos cantos datos in contu de sa cunfiguratzione tua atuale e de s'impreu.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Damus cara meda a sa riservadesa tua. S'imbiu de datos est disativadu in modalidade predefinida e, si sèberas de dd'ativare, in antis s'ant a pònnere comente anònimos. Tenes sa facultade de seberare ite cumpartzire. A pustis de àere retzidu su torracontu, su pretzedente nch'est bogadu. càrriga unu torracontu bòidu pro eliminare totu is datos memorizados immoe in su serbidore",
    "Send new report now" : "Imbia unu torracontu nou immoe",
    "Send usage survey monthly" : "Imbia cada mese su sondàgiu de impreu",
    "Data to send" : "Datos de imbiare",
    "Last report sent on: %s" : "Ùrtima relata imbiada su: %s",
    "Last report" : "Ùrtimu torracontu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/survey_client/l10n/sc.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Ùrtima relata imbiada su: {on}",
    "An error occurred while sending your report." : "B'at àpidu un'errore in s'imbiu de su torracontu.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Elencu de aplicatziones <em>(pro cada aplicatzione: nùmene, versione, istadu de ativatzione)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente de sa base de datos <em>(genia, versione, mannària de sa base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informatziones de tzifradura <em>(ativada est?, cal'est su mòdulu predefinidu)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Nùmeru de cumpartziduras <em>(pro genia e permissos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versione, lìmite di memòria, tempu de esecutzione max., mannària de is archìvios max.)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detàllios istàntzia de su serbidore<em>(versione, memcache impreada, istadu de blocu/anteprimas/avatar)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Istatìsticas <em>(nùmeru de archìvios: archìviu, utentes, archiviatziones pro genia, cummentos e etichetas)</em>",
    "Usage survey" : "Sondàgiu de impreu",
    "Help improve Nextcloud" : "Agiuda·nos a megiorare Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nos boles agiudare a megiorare Nextcloud fruninde unos cantos datos in forma anònima in contu de sa cunfiguratzione e impreu tuos? Podes disativare in cada momentu in is impostatziones de amministratzione.",
    "Not now" : "No immoe",
    "Send usage" : "Imbia impreu",
    "Never" : "Mai",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Imbia datos in forma anònima a Nextcloud pro nos agiudare a ddu megiorare.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Podes cuntribuire a megiorare Nextcloud imbiende unos cantos datos in contu de sa cunfiguratzione tua atuale e de s'impreu.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Damus cara meda a sa riservadesa tua. S'imbiu de datos est disativadu in modalidade predefinida e, si sèberas de dd'ativare, in antis s'ant a pònnere comente anònimos. Tenes sa facultade de seberare ite cumpartzire. A pustis de àere retzidu su torracontu, su pretzedente nch'est bogadu. càrriga unu torracontu bòidu pro eliminare totu is datos memorizados immoe in su serbidore",
    "Send new report now" : "Imbia unu torracontu nou immoe",
    "Send usage survey monthly" : "Imbia cada mese su sondàgiu de impreu",
    "Data to send" : "Datos de imbiare",
    "Last report sent on: %s" : "Ùrtima relata imbiada su: %s",
    "Last report" : "Ùrtimu torracontu",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Imbia datos in forma anònima a Nextcloud pro nos agiudare a megiorare Nextcloud. As a tènnere\n        semper su controllu prenu de is cuntenutos imbiados a  Nextcloud e podes disabilitare\n        custa funtzione in cada momentu."
},
"nplurals=2; plural=(n != 1);");
